//////////////////////////////////////////////////////////////////////////////////////////////////////////////
var selLoader = {
    loadingContainerId: "#loading-container",
    loadingContainerTxt: "#loading-text",
    itemContainer: ".item-container",
    cardsContainer: ".cards-container",
    pageContainers: "header, .dynamics",
    contentLoaderTargets: ".nuggets",
    navItem: ".nav-item",
    navSettings: ".settings",
    navHome: ".home",
    navDashboard: ".dashboard",
    navManage: ".manage",
    navReports: ".reports",
    navAdmin: ".admin",
    navAlerts: ".alerts",
    activitymonitor: ".activity-monitor",
    mngDevItem: ".dropdown-manage > ul > li:first-child",
    mngSvcItem: ".dropdown-manage > ul > li:nth-child(2)",
    dshPmItem: "#topMenu-Dashboard-PatchMgmt",
    dshAVItem: "#topMenu-Dashboard-AntiVirus",
    dshEPSItem: "#topMenu-Dashboard-EndPointControl",
    mainLoader: ".content-loading-container",

    sidebarItem: ".sidebar-item",
    tab: ".tab",
    btnTogTabParent: ".tabs-name-container ul li",
    btnTogTab: ".btn-tog-tab",
    loadingSpinner: ".loading-spinner"
};

var fadeTime = 100;

var loadingContainerClasses = ["device-loading", "more-device-loading", "main-loader", "page-content", "page-action", "content-loader"];

///////////////////////////////////////////////////////////////////////////////////////////////////////////////

// Check to see if loading container has any of the classes which specify that the loading container is activated more than once.
// If it is activated more than once, then each activation sould be followed by de-activation. Each one of them removes its class
// and the last one receives true from this method and de-activates the loading container.
function loadingContainerHasAnyClasses() {
    var loader = $(selLoader.loadingContainerId);
    for (var i in loadingContainerClasses) {
        if ($(loader).hasClass(loadingContainerClasses[i]))
            return true;
    }
    return false;
}

// Since all the functions when activating UI loader, operate on the same div element (#loadingContainer), 
// they should respect each others activation and de-activation. Each one when shows the div element, adds a class to 
// show that it has changed the div element visibility. Check to see if other functions have not done any 
// operation on #loadingContainer. If they did, don't hide the element. The last loader, 
// when removes its class, and observes that there is no other function waiting to hide the loader, 
// then it will hide the loader.
function checkAndFadeOutTheLoader() {
    var canFadeOut = !loadingContainerHasAnyClasses();
    if (canFadeOut) {
        $(selLoader.loadingContainerId).fadeOut(fadeTime);
    }
}

//////////////////////////////////////////////////////////////////////////////////////////////////////////////


//set selected main nav item
function setSelectedNavItem(targetItem) {
    $(selLoader.navItem).removeClass("selected");
    $(selLoader.navItem).find(".nav-dropdown ul li").removeClass("selected");
    $(selLoader.navItem + targetItem).addClass("selected");
}

function setSelectedSidebarItem(targetItem) {
    $(selLoader.sidebarItem).removeClass("selected");
    $(selLoader.sidebarItem + targetItem).addClass("selected");
}

function hidePageLoader() {
    $(selLoader.loadingContainerId).fadeOut(fadeTime);
    $(selLoader.loadingContainerId).removeClass();

    $(selLoader.pageContainers).fadeIn(fadeTime);
}

function showContentLoader() {
    $(selLoader.loadingContainerId).fadeIn(fadeTime).removeClass("content-loader").addClass("content-loader");
    $(selLoader.contentLoaderTargets).fadeOut(fadeTime);
}

function hideContentLoader() {
    $(selLoader.contentLoaderTargets).fadeIn(fadeTime);
    $(selLoader.loadingContainerId).removeClass("content-loader");

    checkAndFadeOutTheLoader();
}

function GetSelectedSidebarItem() {
    return $(selLoader.itemContainer).find(".selected").find("a").data("category");
}

//Applies to page action
function showPageActionLoader(action) {
    $(selLoader.loadingContainerId).fadeIn(fadeTime).removeClass("page-action").addClass("page-action");
    $(selLoader.loadingContainerTxt).text(action);
}

//Applies to page action
function hidePageActionLoader() {
    $(selLoader.loadingContainerId).removeClass("page-action");
    $(selLoader.loadingContainerTxt).text("");

    checkAndFadeOutTheLoader();
}


//Applies to page loadup
function showPageContentLoader(action) {
    $(selLoader.loadingContainerId).fadeIn(fadeTime).removeClass("page-content").addClass("page-content");
    $(".nuggets, aside, main").fadeOut(fadeTime);

    $(selLoader.loadingContainerTxt).html(action);
}

//Applies to page loadup
function hidePageContentLoader() {
    $(selLoader.loadingContainerId).removeClass("page-content");
    $(".nuggets, aside, main").fadeIn(fadeTime);
    $(selLoader.loadingContainerTxt).html("");

    checkAndFadeOutTheLoader();
}

//show loading spinner that covers only main area - used in settings, reports, notification pages
function showMainLoader() {
    $(selLoader.loadingContainerId).fadeIn(fadeTime).removeClass("main-loader").addClass("main-loader");
    $("main").addClass("no-overflow-y");
}

//hide loading spinner that covers only main area - used in settings, reports, notification pages
function hideMainLoader() {
    $(selLoader.loadingContainerId).removeClass("main-loader");
    $("main").removeClass("no-overflow-y");

    checkAndFadeOutTheLoader();
}

//Applies to full page loadup
function showUILoader(action) {
    $(selLoader.loadingContainerId).fadeIn(fadeTime);
    $(selLoader.pageContainers).fadeOut(fadeTime);

    $(selLoader.loadingContainerTxt).html(action);
}

//Applies to full page loadup
function hideUILoader() {
    $(selLoader.pageContainers).fadeIn(fadeTime);

    $(selLoader.loadingContainerTxt).html("");

    checkAndFadeOutTheLoader();
}

//When a group loads the devices
function showLoadingDevices() {
    $(selLoader.loadingContainerId).fadeIn(fadeTime).removeClass("device-loading").addClass("device-loading");
    $(selLoader.cardsContainer).fadeOut(fadeTime);
}

//When a group loads the devices
function hideLoadingDevices() {
    $(selLoader.loadingContainerId).removeClass("device-loading");
    $(selLoader.cardsContainer).fadeIn(fadeTime);

    checkAndFadeOutTheLoader();
}

//When a list of devices scrolls
function showLoadingMoreDevices() {
    $(selLoader.loadingContainerId).fadeIn(fadeTime).removeClass("more-device-loading").addClass("more-device-loading");
    $(selLoader.cardsContainer).fadeOut(fadeTime);
}

//When a list of devices scrolls
function hideLoadingMoreDevices() {
    $(selLoader.loadingContainerId).removeClass("more-device-loading");
    $(selLoader.cardsContainer).fadeIn(fadeTime);

    checkAndFadeOutTheLoader();
}


function SetUIForHome() {
    if ($("body").hasClass("nagware-active"))
        $("body").removeClass().addClass("page-home nagware-active");
    else
        $("body").removeClass().addClass("page-home");

    setSelectedNavItem(selLoader.navHome);

    InitialiseSideNav("body");
    InitialisePrompts("body");
    InitialiseUiMessages("body");
    InitialiseICheck("body");
    InitialiseCards("body");
    InitialiseSelector("body");
    InitialiseDashboardOverview("body");

    hidePageContentLoader();
}

function SetUIForPatchManagementDashboard() {
    if ($("body").hasClass("nagware-active"))
        $("body").removeClass().addClass("page-dashboard nagware-active");
    else
        $("body").removeClass().addClass("page-dashboard");

    $(".nav-item").removeClass("selected")
    setSelectedNavItem(selLoader.navDashboard);
    $(selLoader.dshPmItem).parents("li").addClass("selected");
}

function SetUIForAntiVirusDashboard() {
    if ($("body").hasClass("nagware-active"))
        $("body").removeClass().addClass("page-dashboard nagware-active");
    else
        $("body").removeClass().addClass("page-dashboard");

    $(".nav-item").removeClass("selected")
    setSelectedNavItem(selLoader.navDashboard);
    $(selLoader.dshAVItem).parents("li").addClass("selected");
}

function SetUIForEndpointControlDashboard() {
    if ($("body").hasClass("nagware-active"))
        $("body").removeClass().addClass("page-dashboard nagware-active");
    else
        $("body").removeClass().addClass("page-dashboard");

    $(".nav-item").removeClass("selected")
    setSelectedNavItem(selLoader.navDashboard);
    $(selLoader.dshEPSItem).parents("li").addClass("selected");
}

function SetUIForManageDevices() {
    if ($("body").hasClass("nagware-active"))
        $("body").removeClass().addClass("sidebar-left manage-devices nagware-active");
    else
        $("body").removeClass().addClass("sidebar-left manage-devices");
    $(".nav-item").removeClass("selected")
    setSelectedNavItem(selLoader.navManage);
    $(selLoader.mngDevItem).addClass("selected");
}

function SetUIForManageServices() {
    if ($("body").hasClass("nagware-active"))
        $("body").removeClass().addClass("sidebar-left manage-services nagware-active");
    else
        $("body").removeClass().addClass("sidebar-left manage-services");
    $(".nav-item").removeClass("selected")
    setSelectedNavItem(selLoader.navManage);
    $(selLoader.mngSvcItem).addClass("selected");
}

function SetUIForReports() {
    if ($("body").hasClass("nagware-active"))
        $("body").removeClass().addClass("sidebar-left page-reports nagware-active");
    else
        $("body").removeClass().addClass("sidebar-left page-reports");

    $(".nav-item").removeClass("selected")
    setSelectedNavItem(selLoader.navReports);
}

function SetUIForNotifications() {
    if ($("body").hasClass("nagware-active"))
        $("body").removeClass().addClass("sidebar-left page-notifications-center nagware-active");
    else
        $("body").removeClass().addClass("sidebar-left page-notifications-center");
    $(".nav-item").removeClass("selected")
    setSelectedNavItem(selLoader.navAlerts);
}

function SetUIForRolesAndPermissions() {
    if ($("body").hasClass("nagware-active"))
        $("body").removeClass().addClass("sidebar-left page-settings nagware-active");
    else
        $("body").removeClass().addClass("sidebar-left page-settings");

    $(".nav-item").removeClass("selected")
    setSelectedNavItem(selLoader.navSettings);
}

function SetUIForUserSettings() {
    if ($("body").hasClass("nagware-active"))
        $("body").removeClass().addClass("sidebar-left user-profile page-settings nagware-active");
    else
        $("body").removeClass().addClass("sidebar-left user-profile page-settings");
    $(".nav-item").removeClass("selected")
    setSelectedNavItem(selLoader.navAdmin);
    hidePageContentLoader();
}

function SetUIForActivityMonitor() {
    if ($("body").hasClass("nagware-active"))
        $("body").removeClass().addClass("sidebar-left page-activity-monitor nagware-active");
    else
        $("body").removeClass().addClass("sidebar-left page-activity-monitor");
    $(".nav-item").removeClass("selected")
    setSelectedNavItem(selLoader.activitymonitor);
}

function showCardLoadingSpinner(targetCard) {
    $(targetCard + " " + selLoader.tab).hide();
    $(targetCard + " " + selLoader.btnTogTab).removeClass("active");
    $(selLoader.loadingContainerId).fadeIn(fadeTime);
}

function hideCardLoadingSpinner(targetCard, targetTab) {
    trimmedTargetTab = targetTab.trim();

    $(selLoader.loadingContainerId).fadeOut(fadeTime);
    $(targetCard).find(selLoader.btnTogTabParent).filter("[data-target='" + trimmedTargetTab + "']").find(selLoader.btnTogTab).addClass("active");
    $(targetCard + " ." + targetTab).show();
}

function hideAllCardLoadingSpinner() {
    $(selLoader.loadingSpinner).parent().hide();
}

//////////////////////////////////////////////////////////////////////////////////////////////////////////////

